@@ -75,7 +75,7 @@ public class DataType extends DataTypeActiveRecord {
         return name;
     }
 
-    void setName(final String name) {
+    public void setName(final String name) {
         this.name = name;
     }
 
