@@ -133,17 +133,17 @@ public class DMNMarshaller {
     private DMNDiagramsSession dmnDiagramsSession;
 
     protected DMNMarshaller() {
-        this(null);
+        this(null, null);
     }
 
     @Inject
-    public DMNMarshaller(final FactoryManager factoryManager) {
+    public DMNMarshaller(final FactoryManager factoryManager, final DMNDiagramsSession dmnDiagramsSession) {
         this.inputDataConverter = new InputDataConverter(factoryManager);
         this.decisionConverter = new DecisionConverter(factoryManager);
         this.bkmConverter = new BusinessKnowledgeModelConverter(factoryManager);
         this.knowledgeSourceConverter = new KnowledgeSourceConverter(factoryManager);
         this.textAnnotationConverter = new TextAnnotationConverter(factoryManager);
-        this.decisionServiceConverter = new DecisionServiceConverter(factoryManager);
+        this.decisionServiceConverter = new DecisionServiceConverter(factoryManager, dmnDiagramsSession);
     }
 
     @PostConstruct
@@ -213,9 +213,16 @@ public class DMNMarshaller {
                 if (viewDefinition instanceof DRGElement) {
                     final DRGElement drgElement = (DRGElement) viewDefinition;
                     if (!drgElement.isAllowOnlyVisualChange()) {
-                        nodes.put(drgElement.getId().getValue(),
-                                  stunnerToDMN(withIncludedModels(node, definitionsStunnerPojo),
-                                               componentWidthsConsumer));
+                        if (nodes.containsKey(drgElement.getId().getValue())) {
+                            final JSITDRGElement currentValue = nodes.get(drgElement.getId().getValue());
+                            mergeNodeRequirements(stunnerToDMN(withIncludedModels(node, definitionsStunnerPojo),
+                                                               componentWidthsConsumer),
+                                                  currentValue);
+                        } else {
+                            nodes.put(drgElement.getId().getValue(),
+                                      stunnerToDMN(withIncludedModels(node, definitionsStunnerPojo),
+                                                   componentWidthsConsumer));
+                        }
                     }
                     final String namespaceURI = definitionsStunnerPojo.getDefaultNamespace();
                     diagram.addDMNDiagramElement(WrapperUtils.getWrappedJSIDMNShape(diagram,
@@ -249,7 +256,7 @@ public class DMNMarshaller {
             }
 
             nodes.values().forEach(node -> {
-                mergeOrAddNodeToDefinitions(node, definitions);
+                addNodeToDefinitionsIfNotPresent(node, definitions);
             });
 
             textAnnotations.values().forEach(text -> {
@@ -278,7 +285,8 @@ public class DMNMarshaller {
             for (final Node<?, ?> node : diagramNodes) {
                 PointUtils.convertToRelativeBounds(node);
             }
-        };
+        }
+        ;
 
         return definitions;
     }
@@ -331,20 +339,17 @@ public class DMNMarshaller {
         return Optional.empty();
     }
 
-    void mergeOrAddNodeToDefinitions(final JSITDRGElement node,
-                                     final JSITDefinitions definitions) {
+    void addNodeToDefinitionsIfNotPresent(final JSITDRGElement node,
+                                          final JSITDefinitions definitions) {
 
         final Optional<JSITDRGElement> existingNode = getExistingNode(definitions, node);
 
-        if (existingNode.isPresent()) {
-            final JSITDRGElement existingDRGElement = Js.uncheckedCast(existingNode.get());
-            mergeNodeRequirements(node, existingDRGElement);
-        } else {
+        if (!existingNode.isPresent()) {
             addNodeToDefinitions(node, definitions);
         }
     }
 
-    private void addNodeToDefinitions(final JSITDRGElement node,
+    void addNodeToDefinitions(final JSITDRGElement node,
                                       final JSITDefinitions definitions) {
 
         final JSINodeLocalPartName localPart = getLocalPart(node);
@@ -358,8 +363,8 @@ public class DMNMarshaller {
         return WrapperUtils.getWrappedJSITDRGElement(node, PREFIX, localPart.getLocalPart());
     }
 
-    private void mergeNodeRequirements(final JSITDRGElement node,
-                                       final JSITDRGElement existingDRGElement) {
+    void mergeNodeRequirements(final JSITDRGElement node,
+                               final JSITDRGElement existingDRGElement) {
 
         if (instanceOfBusinessKnowledgeModel(node)) {
 
