@@ -40,9 +40,11 @@ import org.kie.workbench.common.dmn.client.editors.types.common.ScrollHelper;
 import org.kie.workbench.common.dmn.client.editors.types.imported.ImportDataObjectModal;
 import org.kie.workbench.common.dmn.client.editors.types.listview.draganddrop.DNDListComponent;
 import org.kie.workbench.common.dmn.client.editors.types.search.DataTypeSearchBar;
+import org.kie.workbench.common.stunner.core.client.ReadOnlyProvider;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
 import org.mockito.Mock;
+import org.mockito.Mockito;
 import org.uberfire.mocks.EventSourceMock;
 
 import static org.junit.Assert.assertEquals;
@@ -55,8 +57,7 @@ import static org.kie.workbench.common.dmn.client.editors.types.listview.DataTyp
 import static org.kie.workbench.common.dmn.client.editors.types.listview.DataTypeListItemView.UUID_ATTR;
 import static org.kie.workbench.common.dmn.client.editors.types.listview.common.ListItemViewCssHelper.RIGHT_ARROW_CSS_CLASS;
 import static org.kie.workbench.common.dmn.client.resources.i18n.DMNEditorConstants.DataTypeSuccessfullyImportedMessage_StrongMessage;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.anyString;
+import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.Mockito.doNothing;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
@@ -71,18 +72,6 @@ public class DataTypeListViewTest {
     @Mock
     private HTMLDivElement listItems;
 
-    @Mock
-    private HTMLDivElement collapsedDescription;
-
-    @Mock
-    private HTMLDivElement expandedDescription;
-
-    @Mock
-    private HTMLAnchorElement viewMore;
-
-    @Mock
-    private HTMLAnchorElement viewLess;
-
     @Mock
     private HTMLElement element;
 
@@ -140,6 +129,15 @@ public class DataTypeListViewTest {
     @Mock
     private TranslationService translationService;
 
+    @Mock
+    private HTMLButtonElement addButtonPlaceholder;
+
+    @Mock
+    private HTMLDivElement dataTypeButton;
+
+    @Mock
+    private ReadOnlyProvider readOnlyProvider;
+
     @Captor
     private ArgumentCaptor<FlashMessage> flashMessageCaptor;
 
@@ -156,9 +154,10 @@ public class DataTypeListViewTest {
         placeholder.classList = mock(DOMTokenList.class);
         noDataTypesFound.classList = mock(DOMTokenList.class);
         listItems.classList = mock(DOMTokenList.class);
+        dataTypeButton.classList = mock(DOMTokenList.class);
         listItems.childNodes = new NodeList<>();
 
-        view = spy(new DataTypeListView(listItems, collapsedDescription, expandedDescription, viewMore, viewLess, addButton, placeholder, searchBarContainer, expandAll, collapseAll, noDataTypesFound, readOnlyMessage, readOnlyMessageCloseButton, scrollHelper, importDataObjectButton, importDataObjectModal, flashMessageEvent, translationService));
+        view = spy(new DataTypeListView(listItems, addButton, addButtonPlaceholder, dataTypeButton, placeholder, searchBarContainer, expandAll, collapseAll, noDataTypesFound, readOnlyMessage, readOnlyMessageCloseButton, scrollHelper, importDataObjectButton, importDataObjectModal, flashMessageEvent, translationService, readOnlyProvider));
         view.init(presenter);
 
         doReturn(element).when(view).getElement();
@@ -169,6 +168,27 @@ public class DataTypeListViewTest {
         // "view.init(..)" called in the setup.
         verify(searchBarContainer).appendChild(searchBarElement);
         verify(listItems).appendChild(dndListComponentElement);
+        verify(view).setupAddButtonReadOnlyStatus();
+    }
+
+    @Test
+    public void testSetupAddButtonReadOnlyStatusWhenIsReadOnly() {
+
+        when(readOnlyProvider.isReadOnlyDiagram()).thenReturn(true);
+
+        view.setupAddButtonReadOnlyStatus();
+
+        assertTrue(addButton.disabled);
+    }
+
+    @Test
+    public void testSetupAddButtonReadOnlyStatusWhenIsNotReadOnly() {
+
+        when(readOnlyProvider.isReadOnlyDiagram()).thenReturn(false);
+
+        view.setupAddButtonReadOnlyStatus();
+
+        assertFalse(addButton.disabled);
     }
 
     @Test
@@ -210,10 +230,6 @@ public class DataTypeListViewTest {
     @Test
     public void testShowNoDataTypesFound() {
 
-        noDataTypesFound.classList = mock(DOMTokenList.class);
-        placeholder.classList = mock(DOMTokenList.class);
-        listItems.classList = mock(DOMTokenList.class);
-
         view.showNoDataTypesFound();
 
         verify(noDataTypesFound.classList).remove(HIDDEN_CSS_CLASS);
@@ -224,29 +240,23 @@ public class DataTypeListViewTest {
     @Test
     public void testShowListItems() {
 
-        noDataTypesFound.classList = mock(DOMTokenList.class);
-        placeholder.classList = mock(DOMTokenList.class);
-        listItems.classList = mock(DOMTokenList.class);
-
         view.showListItems();
 
         verify(noDataTypesFound.classList).add(HIDDEN_CSS_CLASS);
         verify(placeholder.classList).add(HIDDEN_CSS_CLASS);
         verify(listItems.classList).remove(HIDDEN_CSS_CLASS);
+        verify(dataTypeButton.classList).remove(HIDDEN_CSS_CLASS);
     }
 
     @Test
     public void testShowPlaceHolder() {
 
-        noDataTypesFound.classList = mock(DOMTokenList.class);
-        placeholder.classList = mock(DOMTokenList.class);
-        listItems.classList = mock(DOMTokenList.class);
-
         view.showPlaceHolder();
 
         verify(noDataTypesFound.classList).add(HIDDEN_CSS_CLASS);
         verify(placeholder.classList).remove(HIDDEN_CSS_CLASS);
         verify(listItems.classList).add(HIDDEN_CSS_CLASS);
+        verify(dataTypeButton.classList).add(HIDDEN_CSS_CLASS);
     }
 
     @Test
@@ -255,7 +265,7 @@ public class DataTypeListViewTest {
         final DataType dataType = mock(DataType.class);
         final String uuid = "uuid";
 
-        doNothing().when(view).cleanSubTypes(anyString());
+        doNothing().when(view).cleanSubTypes(Mockito.<String>any());
         when(dataType.getUUID()).thenReturn(uuid);
 
         view.cleanSubTypes(dataType);
@@ -313,7 +323,7 @@ public class DataTypeListViewTest {
         when(listItem1.getDragAndDropElement()).thenReturn(listItemElement1);
         when(listItem2.getDragAndDropElement()).thenReturn(listItemElement2);
 
-        doNothing().when(view).cleanSubTypes(anyString());
+        doNothing().when(view).cleanSubTypes(Mockito.<String>any());
         doNothing().when(view).hideItemElementIfParentIsCollapsed(any(), any());
         doNothing().when(view).showArrowIconIfDataTypeHasChildren(any());
 
@@ -333,7 +343,7 @@ public class DataTypeListViewTest {
 
         final ClickEvent event = mock(ClickEvent.class);
 
-        view.onAddClick(event);
+        view.onAddButtonClick(event);
 
         verify(scrollHelper).animatedScrollToBottom(listItems);
         verify(presenter).addDataType();
@@ -431,7 +441,7 @@ public class DataTypeListViewTest {
         final String uuid = "uuid";
 
         dataTypeRowArrow.classList = arrowClassList;
-        elementNodeList.length = 1d;
+        elementNodeList.length = 1;
 
         when(dataType.getUUID()).thenReturn(uuid);
         when(listItems.querySelectorAll("[" + PARENT_UUID_ATTR + "=\"uuid\"]")).thenReturn(elementNodeList);
@@ -454,7 +464,7 @@ public class DataTypeListViewTest {
         final String uuid = "uuid";
 
         dataTypeRowArrow.classList = arrowClassList;
-        elementNodeList.length = 0d;
+        elementNodeList.length = 0;
 
         when(dataType.getUUID()).thenReturn(uuid);
         when(listItems.querySelectorAll("[" + PARENT_UUID_ATTR + "=\"uuid\"]")).thenReturn(elementNodeList);
@@ -466,47 +476,6 @@ public class DataTypeListViewTest {
         verify(arrowClassList).add(HIDDEN_CSS_CLASS);
     }
 
-    @Test
-    public void testSetup() {
-        view.setup();
-
-        verify(view).collapseDescription();
-    }
-
-    @Test
-    public void testOnClickViewMore() {
-        view.onClickViewMore(mock(ClickEvent.class));
-
-        verify(view).expandDescription();
-    }
-
-    @Test
-    public void testOnClickViewLess() {
-        view.onClickViewLess(mock(ClickEvent.class));
-
-        verify(view).collapseDescription();
-    }
-
-    @Test
-    public void testExpandDescription() {
-        view.expandDescription();
-
-        assertTrue(collapsedDescription.hidden);
-        assertFalse(expandedDescription.hidden);
-        assertFalse(viewLess.hidden);
-        assertTrue(viewMore.hidden);
-    }
-
-    @Test
-    public void testCollapseDescription() {
-        view.collapseDescription();
-
-        assertFalse(collapsedDescription.hidden);
-        assertTrue(expandedDescription.hidden);
-        assertTrue(viewLess.hidden);
-        assertFalse(viewMore.hidden);
-    }
-
     @Test
     public void testRemoveItem() {
 
@@ -517,7 +486,7 @@ public class DataTypeListViewTest {
 
         when(dataType.getUUID()).thenReturn(uuid);
         doReturn(dataTypeElement).when(view).getDataTypeRow(dataType);
-        doNothing().when(view).cleanSubTypes(anyString());
+        doNothing().when(view).cleanSubTypes(Mockito.<String>any());
         dataTypeElement.parentNode = parentNode;
 
         view.removeItem(dataType);
