@@ -23,17 +23,19 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+
 import javax.enterprise.inject.Instance;
 
+import org.guvnor.common.services.project.categories.Form;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.forms.editor.backend.indexing.query.FindFormDefinitionIdsQuery;
 import org.kie.workbench.common.forms.editor.type.FormResourceTypeDefinition;
 import org.kie.workbench.common.forms.fields.test.TestMetaDataEntryManager;
 import org.kie.workbench.common.forms.model.FormModel;
-import org.kie.workbench.common.forms.serialization.impl.FieldSerializer;
-import org.kie.workbench.common.forms.serialization.impl.FormDefinitionSerializerImpl;
-import org.kie.workbench.common.forms.serialization.impl.FormModelSerializer;
+import org.kie.workbench.common.forms.services.backend.serialization.impl.FieldSerializer;
+import org.kie.workbench.common.forms.services.backend.serialization.impl.FormDefinitionSerializerImpl;
+import org.kie.workbench.common.forms.services.backend.serialization.impl.FormModelSerializer;
 import org.kie.workbench.common.services.refactoring.backend.server.BaseIndexingTest;
 import org.kie.workbench.common.services.refactoring.backend.server.TestIndexer;
 import org.kie.workbench.common.services.refactoring.backend.server.query.NamedQuery;
@@ -46,12 +48,18 @@ import org.kie.workbench.common.services.refactoring.model.index.terms.valueterm
 import org.kie.workbench.common.services.refactoring.model.query.RefactoringPageRequest;
 import org.kie.workbench.common.services.refactoring.model.query.RefactoringPageRow;
 import org.kie.workbench.common.services.refactoring.service.ResourceType;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 import org.uberfire.java.nio.file.Path;
 import org.uberfire.paging.PageResponse;
 
-import static org.junit.Assert.*;
-import static org.mockito.Mockito.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+import static org.mockito.Mockito.any;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.when;
 
 @RunWith(MockitoJUnitRunner.class)
 public class FormDefinitionIndexerTest extends BaseIndexingTest<FormResourceTypeDefinition> {
@@ -68,16 +76,12 @@ public class FormDefinitionIndexerTest extends BaseIndexingTest<FormResourceType
             "testTask-taskform.frm"
     };
 
-    private FormModelVisitorProvider provider;
-
-    private FormModelVisitor visitor;
-
     private TestFormDefinitionIndexer indexer;
 
     @Override
     public void setup() throws IOException {
-        visitor = mock(FormModelVisitor.class);
-        provider = mock(FormModelVisitorProvider.class);
+        FormModelVisitor visitor = mock(FormModelVisitor.class);
+        FormModelVisitorProvider provider = mock(FormModelVisitorProvider.class);
         when(provider.getModelType()).thenReturn(FormModel.class);
         when(provider.getVisitor()).thenReturn(visitor);
 
@@ -87,7 +91,7 @@ public class FormDefinitionIndexerTest extends BaseIndexingTest<FormResourceType
 
         when(providersInstance.iterator()).thenReturn(providers.iterator());
 
-        indexer = spy(new TestFormDefinitionIndexer(new FormResourceTypeDefinition(),
+        indexer = spy(new TestFormDefinitionIndexer(new FormResourceTypeDefinition(new Form()),
                                                     new FormDefinitionSerializerImpl(new FieldSerializer(),
                                                                                      new FormModelSerializer(),
                                                                                      new TestMetaDataEntryManager()),
@@ -102,6 +106,7 @@ public class FormDefinitionIndexerTest extends BaseIndexingTest<FormResourceType
     public void testFormsIndexing() throws Exception {
         List<Path> pathList = new ArrayList<>();
 
+        ioService().startBatch(ioService().getFileSystem(basePath.toUri()));
         for (String formFile : FORMS) {
             Path path = basePath.resolve(formFile);
             pathList.add(path);
@@ -109,6 +114,7 @@ public class FormDefinitionIndexerTest extends BaseIndexingTest<FormResourceType
             ioService().write(path,
                               formContent);
         }
+        ioService().endBatch();
 
         Path[] paths = pathList.toArray(new Path[pathList.size()]);
 
@@ -127,20 +133,22 @@ public class FormDefinitionIndexerTest extends BaseIndexingTest<FormResourceType
             }
 
             assertNotNull(response);
+
+            Set<RefactoringPageRow> result = new HashSet(response.getPageRowList());
+
             assertEquals(paths.length,
-                         response.getPageRowList().size());
+                         result.size());
         }
         {
-
             final Set<ValueIndexTerm> queryTerms = new HashSet<ValueIndexTerm>() {{
                 add(new ValueResourceIndexTerm("*",
                                                ResourceType.FORM,
                                                ValueIndexTerm.TermSearchType.WILDCARD));
             }};
             try {
-                List<RefactoringPageRow> response = service.query(
+                Set<RefactoringPageRow> response = new HashSet(service.query(
                         FindFormDefinitionIdsQuery.NAME,
-                        queryTerms);
+                        queryTerms));
                 assertNotNull(response);
                 assertEquals(paths.length,
                              response.size());
@@ -202,7 +210,7 @@ public class FormDefinitionIndexerTest extends BaseIndexingTest<FormResourceType
 
     @Override
     protected String getRepositoryName() {
-        return this.getClass().getSimpleName();
+        return testName.getMethodName();
     }
 
     @Override
@@ -212,6 +220,6 @@ public class FormDefinitionIndexerTest extends BaseIndexingTest<FormResourceType
 
     @Override
     protected FormResourceTypeDefinition getResourceTypeDefinition() {
-        return new FormResourceTypeDefinition();
+        return new FormResourceTypeDefinition(new Form());
     }
 }
