@@ -17,7 +17,7 @@
 package org.kie.workbench.common.workbench.client.entrypoint;
 
 import java.util.Map;
-import javax.annotation.PostConstruct;
+
 import javax.inject.Inject;
 
 import com.google.gwt.animation.client.Animation;
@@ -25,32 +25,41 @@ import com.google.gwt.dom.client.Element;
 import com.google.gwt.dom.client.Style;
 import com.google.gwt.user.client.ui.RootPanel;
 import org.guvnor.common.services.shared.config.AppConfigService;
+import org.jboss.errai.bus.client.api.messaging.Message;
+import org.jboss.errai.bus.client.framework.AbstractRpcProxy;
+import org.jboss.errai.bus.client.util.BusToolsCli;
 import org.jboss.errai.common.client.api.Caller;
-import org.jboss.errai.common.client.api.RemoteCallback;
+import org.jboss.errai.common.client.api.ErrorCallback;
 import org.jboss.errai.ioc.client.api.AfterInitialization;
 import org.jboss.errai.ioc.client.api.UncaughtExceptionHandler;
 import org.kie.workbench.common.services.shared.preferences.ApplicationPreferences;
 import org.kie.workbench.common.widgets.client.resources.RoundedCornersResource;
 import org.kie.workbench.common.workbench.client.error.DefaultWorkbenchErrorCallback;
-import org.slf4j.Logger;
 import org.uberfire.client.mvp.ActivityBeansCache;
 
 public abstract class DefaultWorkbenchEntryPoint {
 
-    @Inject
-    private Logger logger;
-
     protected Caller<AppConfigService> appConfigService;
 
     protected ActivityBeansCache activityBeansCache;
 
-    private DefaultWorkbenchErrorCallback defaultErrorCallback = new DefaultWorkbenchErrorCallback();
+    private DefaultWorkbenchErrorCallback defaultWorkbenchErrorCallback;
+
+    private GenericErrorPopup genericErrorPopup;
 
     @Inject
-    public DefaultWorkbenchEntryPoint(Caller<AppConfigService> appConfigService,
-                                      ActivityBeansCache activityBeansCache) {
+    public DefaultWorkbenchEntryPoint(final Caller<AppConfigService> appConfigService,
+                                      final ActivityBeansCache activityBeansCache,
+                                      final DefaultWorkbenchErrorCallback defaultWorkbenchErrorCallback) {
+
         this.appConfigService = appConfigService;
         this.activityBeansCache = activityBeansCache;
+        this.defaultWorkbenchErrorCallback = defaultWorkbenchErrorCallback;
+    }
+
+    @Inject
+    public void setGenericErrorPopup(final GenericErrorPopup genericErrorPopup) {
+        this.genericErrorPopup = genericErrorPopup;
     }
 
     protected abstract void setupMenu();
@@ -67,22 +76,15 @@ public abstract class DefaultWorkbenchEntryPoint {
     }
 
     @UncaughtExceptionHandler
-    private void handleUncaughtException(Throwable t) {
-        defaultErrorCallback.error(null,
-                                   t);
-
-        logger.error("Uncaught exception encountered",
-                     t);
+    private void handleUncaughtException(final Throwable t) {
+        defaultWorkbenchErrorCallback.error(t);
     }
 
     void loadPreferences() {
-        appConfigService.call(new RemoteCallback<Map<String, String>>() {
-            @Override
-            public void callback(final Map<String, String> response) {
-                ApplicationPreferences.setUp(response);
-                setupMenu();
-                setupAdminPage();
-            }
+        appConfigService.call((final Map<String, String> response) -> {
+            ApplicationPreferences.setUp(response);
+            setupMenu();
+            setupAdminPage();
         }).loadPreferences();
     }
 
@@ -109,7 +111,26 @@ public abstract class DefaultWorkbenchEntryPoint {
     }
 
     protected void initializeWorkbench() {
+        setupRpcDefaultErrorCallback();
         loadPreferences();
         loadStyles();
     }
+
+    protected void setupRpcDefaultErrorCallback() {
+        //FIXME: Some RPC calls are made before this callback has the chance to be registered. Investigate and fix.
+        final ErrorCallback<Message> originalRpcErrorCallback = AbstractRpcProxy.DEFAULT_RPC_ERROR_CALLBACK;
+
+        AbstractRpcProxy.DEFAULT_RPC_ERROR_CALLBACK = (final Message m, final Throwable t) -> {
+
+            //Removing parameter/return information because sensitive data might be encoded.
+            //Also, this is safe because this message is not going to be used anymore.
+            m.remove("MethodParms");
+            m.remove("MethodReply");
+
+            genericErrorPopup.setup(BusToolsCli.encodeMessage(m));
+
+            //This will send a message to Errai Bus' error channel.
+            return originalRpcErrorCallback.error(m, t);
+        };
+    }
 }
