@@ -31,9 +31,9 @@ import static org.kie.workbench.common.services.shared.resources.PerspectiveIds.
 import static org.kie.workbench.common.services.shared.resources.PerspectiveIds.SERVER_MANAGEMENT;
 import static org.kie.workbench.common.services.shared.resources.PerspectiveIds.TASKS;
 import static org.kie.workbench.common.services.shared.resources.PerspectiveIds.TASK_DASHBOARD;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.anyString;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.anyString;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.RETURNS_DEFAULTS;
 import static org.mockito.Mockito.doAnswer;
 import static org.mockito.Mockito.doReturn;
