@@ -32,7 +32,6 @@ import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.DeleteNodeConfirmation;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.SelectionControl;
-import org.kie.workbench.common.stunner.core.client.canvas.controls.keyboard.KeyboardControl.KogitoKeyPress;
 import org.kie.workbench.common.stunner.core.client.canvas.event.registration.CanvasElementsClearEvent;
 import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasClearSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasSelectionEvent;
@@ -50,8 +49,6 @@ import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
 
 import static org.kie.soup.commons.validation.PortablePreconditions.checkNotNull;
 import static org.kie.workbench.common.stunner.core.client.canvas.controls.keyboard.KeysMatcher.doKeysMatch;
-import static org.kie.workbench.common.stunner.core.client.event.keyboard.KeyboardEvent.Key.DELETE;
-import static org.kie.workbench.common.stunner.core.client.event.keyboard.KeyboardEvent.Key.KEY_BACKSPACE;
 
 /**
  * This session command obtains the selected elements on session and executes a delete operation for each one.
@@ -112,16 +109,6 @@ public class DeleteSelectionSessionCommand extends AbstractSelectionAwareSession
     @Override
     public void bind(final EditorSession session) {
         super.bind(session);
-        session.getKeyboardControl().addKeyShortcutCallback(new KogitoKeyPress(new Key[]{KEY_BACKSPACE}, "Edit | Delete selection", () -> {
-            if (isEnabled()) {
-                execute();
-            }
-        }));
-        session.getKeyboardControl().addKeyShortcutCallback(new KogitoKeyPress(new Key[]{DELETE}, "Edit | Delete selection", () -> {
-            if (isEnabled()) {
-                execute();
-            }
-        }));
         session.getKeyboardControl().addKeyShortcutCallback(this::onKeyDownEvent);
         this.canvasCommandFactory = this.loadCanvasFactory(canvasCommandFactoryInstance, definitionUtils);
     }
