@@ -55,6 +55,7 @@ import org.uberfire.mvp.Command;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
@@ -147,6 +148,13 @@ public class DefaultEditorSessionTest {
         verify(managedSession, times(1)).open();
     }
 
+    @Test
+    public void testClose() {
+        tested.close();
+        verify(commandRegistry, never()).clear();
+        verify(managedSession, times(1)).close();
+    }
+
     @Test
     public void testDestroy() {
         tested.destroy();
