@@ -29,20 +29,22 @@ import org.kie.workbench.common.stunner.core.client.shape.view.ShapeView;
 import org.kie.workbench.common.stunner.core.definition.shape.ShapeViewDef;
 import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Node;
+import org.kie.workbench.common.stunner.core.graph.content.Bound;
 import org.kie.workbench.common.stunner.core.graph.content.Bounds;
-import org.kie.workbench.common.stunner.core.graph.content.view.BoundImpl;
 import org.kie.workbench.common.stunner.core.graph.content.view.Point2D;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
+import org.mockito.InOrder;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.eq;
+import static org.mockito.Mockito.inOrder;
 import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class NodeShapeImplTest {
 
     @Mock
@@ -78,6 +80,9 @@ public class NodeShapeImplTest {
     private ShapeViewExtStub view;
     private NodeShapeImpl<Object, ShapeViewDef<Object, ShapeView>, ShapeView> tested;
 
+    @Mock
+    private MutationContext context;
+
     @Before
     public void setup() throws Exception {
         when(shapeStateHandler.shapeAttributesChanged()).thenReturn(shapeStateHandler);
@@ -88,10 +93,10 @@ public class NodeShapeImplTest {
         when(element.getContent()).thenReturn(content);
         when(content.getDefinition()).thenReturn(definition);
         when(content.getBounds()).thenReturn(bounds);
-        when(bounds.getUpperLeft()).thenReturn(new BoundImpl(10d,
-                                                             20d));
-        when(bounds.getLowerRight()).thenReturn(new BoundImpl(50d,
-                                                              60d));
+        when(bounds.getUpperLeft()).thenReturn(Bound.create(10d,
+                                                            20d));
+        when(bounds.getLowerRight()).thenReturn(Bound.create(50d,
+                                                             60d));
 
         this.view = spy(new ShapeViewExtStub());
 
@@ -131,4 +136,12 @@ public class NodeShapeImplTest {
         verify(shapeStateHandler,
                times(1)).applyState(eq(ShapeState.INVALID));
     }
-}
+
+    @Test
+    public void testTitle() {
+        final InOrder order = inOrder(titleHandler, fontHandler);
+        tested.applyTitle("title", element, context);
+        order.verify(fontHandler).accept(definition, view);
+        order.verify(titleHandler).accept("title", view);
+    }
+}
\ No newline at end of file
