@@ -16,6 +16,8 @@
 
 package org.kie.workbench.common.stunner.svg.gen.impl;
 
+import javax.annotation.processing.Messager;
+
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
@@ -24,16 +26,21 @@ import org.kie.workbench.common.stunner.svg.gen.codegen.impl.SVGViewFactoryGener
 import org.kie.workbench.common.stunner.svg.gen.model.ViewFactory;
 import org.kie.workbench.common.stunner.svg.gen.model.impl.ViewDefinitionImpl;
 import org.kie.workbench.common.stunner.svg.gen.translator.SVGDocumentTranslator;
+import org.kie.workbench.common.stunner.svg.gen.translator.SVGTranslatorContext;
 import org.mockito.Mock;
 import org.mockito.invocation.InvocationOnMock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 import org.mockito.stubbing.Answer;
-import org.w3c.dom.Document;
 
-import static org.junit.Assert.*;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.eq;
-import static org.mockito.Mockito.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.eq;
+import static org.mockito.Mockito.doAnswer;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(MockitoJUnitRunner.class)
 public class SVGGeneratorImplTest {
@@ -57,14 +64,13 @@ public class SVGGeneratorImplTest {
 
     @Before
     public void setup() throws Exception {
-        when(translator.translate(any(Document.class))).thenReturn(viewDefinition);
+        when(translator.translate(any(SVGTranslatorContext.class))).thenReturn(viewDefinition);
         tested = new SVGGeneratorImpl(translator,
                                       viewFactoryGenerator);
     }
 
     @Test
     public void testGenerate() throws Exception {
-        when(viewDefinition.getId()).thenReturn("svg-cancel");
         doAnswer(new Answer<StringBuffer>() {
             @Override
             public StringBuffer answer(final InvocationOnMock invocationOnMock) throws Throwable {
@@ -83,7 +89,10 @@ public class SVGGeneratorImplTest {
         }).when(viewFactoryGenerator).generate(any(ViewFactory.class));
         final SVGGeneratorRequest request = new SVGGeneratorRequest(SVG_NAME,
                                                                     SVG_PKG,
-                                                                    SVG_FQCN);
+                                                                    SVG_FQCN,
+                                                                    "",
+                                                                    "MyViewBuilderType.class",
+                                                                    mock(Messager.class));
         request.getViewSources().put(SVG_CANCEL_NAME,
                                      SVG_CANCEL_PATH);
         tested.generate(request);
