@@ -34,6 +34,7 @@ import org.kie.workbench.common.stunner.bpmn.definition.property.event.BaseStart
 import org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.BPMNGeneralSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.SimulationAttributeSet;
+import org.kie.workbench.common.stunner.bpmn.definition.property.variables.AdvancedData;
 import org.kie.workbench.common.stunner.core.definition.annotation.Definition;
 import org.kie.workbench.common.stunner.core.definition.annotation.Property;
 import org.kie.workbench.common.stunner.core.definition.annotation.morph.Morph;
@@ -64,6 +65,7 @@ public class StartNoneEvent extends BaseStartEvent {
              new FontSet(),
              new CircleDimensionSet(new Radius()),
              new SimulationAttributeSet(),
+             new AdvancedData(),
              new BaseStartEventExecutionSet());
     }
 
@@ -72,12 +74,14 @@ public class StartNoneEvent extends BaseStartEvent {
                           final @MapsTo("fontSet") FontSet fontSet,
                           final @MapsTo("dimensionsSet") CircleDimensionSet dimensionsSet,
                           final @MapsTo("simulationSet") SimulationAttributeSet simulationSet,
+                          final @MapsTo("advancedData") AdvancedData advancedData,
                           final @MapsTo("executionSet") BaseStartEventExecutionSet executionSet) {
         super(general,
               backgroundSet,
               fontSet,
               dimensionsSet,
-              simulationSet);
+              simulationSet,
+              advancedData);
         this.executionSet = executionSet;
     }
 
