@@ -40,12 +40,13 @@ import org.kie.workbench.common.stunner.core.graph.command.GraphCommandManager;
 import org.kie.workbench.common.stunner.core.graph.command.impl.GraphCommandFactory;
 import org.kie.workbench.common.stunner.core.graph.content.definition.Definition;
 import org.kie.workbench.common.stunner.core.graph.content.definition.DefinitionSet;
-import org.kie.workbench.common.stunner.core.graph.content.view.Point2D;
 import org.kie.workbench.common.stunner.core.graph.processing.index.GraphIndexBuilder;
 import org.kie.workbench.common.stunner.core.graph.processing.index.Index;
 import org.kie.workbench.common.stunner.core.rule.RuleManager;
 import org.kie.workbench.common.stunner.core.util.UUID;
 
+import static org.kie.workbench.common.stunner.core.definition.adapter.binding.BindableAdapterUtils.getDefinitionId;
+
 /**
  * The custom factory for BPMN graphs.
  * It initializes the BPMN graph with a new Diagram node instance, which represents the main process.
@@ -58,6 +59,8 @@ public class BPMNGraphFactoryImpl
         extends AbstractGraphFactory
         implements BPMNGraphFactory {
 
+    public static final String START_EVENT_ID = getDefinitionId(StartNoneEvent.class);
+
     protected final DefinitionManager definitionManager;
     private final RuleManager ruleManager;
     private final GraphIndexBuilder<?> indexBuilder;
@@ -131,21 +134,17 @@ public class BPMNGraphFactoryImpl
     // Add a BPMN diagram and a start event nodes by default.
     protected List<Command> buildInitialisationCommands() {
         final List<Command> commands = new ArrayList<>();
-        final Node<Definition<BPMNDiagram>, Edge> diagramNode = (Node<Definition<BPMNDiagram>, Edge>) factoryManager.newElement(UUID.uuid(),
-                                                                                                                                diagramType);
-        final Node<Definition<StartNoneEvent>, Edge> startEventNode = (Node<Definition<StartNoneEvent>, Edge>) factoryManager.newElement(UUID.uuid(),
-                                                                                                                                         StartNoneEvent.class);
+        final Node<Definition<BPMNDiagram>, Edge> diagramNode =
+                (Node<Definition<BPMNDiagram>, Edge>) factoryManager.newElement(UUID.uuid(), getDefinitionId(diagramType));
         commands.add(graphCommandFactory.addNode(diagramNode));
-        commands.add(graphCommandFactory.addChildNode(diagramNode,
-                                                      startEventNode,
-                                                      new Point2D(START_X,
-                                                                  START_Y)));
         return commands;
     }
 
     @SuppressWarnings("unchecked")
     protected GraphCommandExecutionContext createGraphContext(final Graph graph) {
-        final Index<?, ?> index = indexBuilder.build(graph);
+        //AF-2542: the new version of JDT used by GWT has a hard time to resolve some generics.
+        //         the unnecessary cast is required because of that.
+        final Index index = (Index) indexBuilder.build(graph);
         return new DirectGraphCommandExecutionContext(definitionManager,
                                                       factoryManager,
                                                       index);
@@ -155,4 +154,4 @@ public class BPMNGraphFactoryImpl
     protected DefinitionManager getDefinitionManager() {
         return definitionManager;
     }
-}
+}
\ No newline at end of file
