@@ -20,6 +20,7 @@ import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.Objects;
 import java.util.Set;
 
 import javax.enterprise.context.Dependent;
@@ -30,9 +31,11 @@ import org.guvnor.common.services.project.model.Module;
 import org.guvnor.common.services.project.model.Package;
 import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.common.client.api.IsElement;
+import org.jboss.errai.common.client.api.RemoteCallback;
 import org.jboss.errai.common.client.dom.HTMLElement;
 import org.kie.workbench.common.services.shared.project.KieModulePackages;
 import org.kie.workbench.common.services.shared.project.KieModuleService;
+import org.kie.workbench.common.services.shared.project.PackageItem;
 import org.uberfire.mvp.Command;
 
 /**
@@ -45,8 +48,8 @@ public class PackageListBox
     private PackageListBoxView view;
     private WorkspaceProjectContext projectContext;
     protected Caller<KieModuleService> moduleService;
-    private Map<String, Package> packages;
-    private String selectedPackage = null;
+    private Map<String, PackageItem> packages;
+    private Package selectedPackage = null;
 
     @Inject
     public PackageListBox(final PackageListBoxView view,
@@ -80,31 +83,29 @@ public class PackageListBox
     private void showListOfPackages(final boolean includeDefaultPackage,
                                     final Command packagesLoadedCommand) {
         final Module activeModule = projectContext.getActiveModule().orElse(null);
-        if (activeModule == null) {
-            return;
-        } else {
+        if (activeModule != null) {
             moduleService.call((KieModulePackages kieModulePackages) -> {
                 //Sort by caption
-                    final List<Package> sortedPackages = getSortedPackages(includeDefaultPackage,
+                final List<PackageItem> sortedPackages = getSortedPackages(includeDefaultPackage,
                                                                            kieModulePackages.getPackages());
 
-                    // Disable and set default content if no Packages available
-                    if (sortedPackages.isEmpty()) {
-                        return;
-                    }
-                    addPackagesToSelect(sortedPackages,
-                                        kieModulePackages.getDefaultPackage());
+                // Disable and set default content if no Packages available
+                if (sortedPackages.isEmpty()) {
+                    return;
+                }
+                addPackagesToSelect(sortedPackages,
+                                    kieModulePackages.getDefaultPackage());
 
-                    if (packagesLoadedCommand != null) {
-                        packagesLoadedCommand.execute();
-                    }
-             }).resolveModulePackages(activeModule);
+                if (packagesLoadedCommand != null) {
+                    packagesLoadedCommand.execute();
+                }
+            }).resolveModulePackages(activeModule);
         }
     }
 
-    private List<Package> getSortedPackages(final boolean includeDefaultPackage,
-                                            final Set<Package> pkgs) {
-        final List<Package> sortedPackages = new ArrayList<>(pkgs);
+    private List<PackageItem> getSortedPackages(final boolean includeDefaultPackage,
+                                                final Set<PackageItem> pkgs) {
+        final List<PackageItem> sortedPackages = new ArrayList<>(pkgs);
         Collections.sort(sortedPackages,
                          (p1, p2) -> p1.getCaption().compareTo(p2.getCaption()));
 
@@ -118,42 +119,59 @@ public class PackageListBox
         return sortedPackages;
     }
 
-    private void addPackagesToSelect(final List<Package> sortedPackages,
+    private void addPackagesToSelect(final List<PackageItem> sortedPackages,
                                      final Package activePackage) {
 
         final Map<String, String> packageNames = new HashMap<>();
 
-        for (Package pkg : sortedPackages) {
+        for (PackageItem pkg : sortedPackages) {
             packageNames.put(pkg.getCaption(),
                              pkg.getPackageName());
             packages.put(pkg.getCaption(),
                          pkg);
         }
 
-        selectedPackage = getSelectedPackage(activePackage,
-                                             packageNames);
+        setSelectedPackage(activePackage);
 
-        view.setUp(selectedPackage,
+        String selectedPackageName = resolve(getSelectedPackageName(activePackage,
+                                                                    packageNames));
+
+        view.setUp(selectedPackageName,
                    packageNames);
     }
 
-    private String getSelectedPackage(final Package activePackage,
-                                      final Map<String, String> packageNames) {
+    private String getSelectedPackageName(final Package activePackage,
+                                          final Map<String, String> packageNames) {
         if (packageNames.containsKey(activePackage.getCaption())) {
+
             return activePackage.getCaption();
         } else if (!packageNames.isEmpty()) {
-            return packageNames.keySet().iterator().next();
+            final String next = packageNames.keySet().iterator().next();
+            setSelectedPackage(next);
+            return next;
         } else {
             return null;
         }
     }
 
-    public Package getSelectedPackage() {
-
-        if (packages.isEmpty()) {
-            return null;
+    private void setSelectedPackage(final String selectedPackage) {
+        final Module activeModule = projectContext.getActiveModule().orElse(null);
+        if (activeModule == null) {
+            return;
+        } else {
+            moduleService
+                    .call((RemoteCallback<Package>) this::setSelectedPackage)
+                    .resolvePackage(activeModule,
+                                    resolve(selectedPackage));
         }
-        return packages.get(selectedPackage);
+    }
+
+    private void setSelectedPackage(final Package selectedPackage) {
+        this.selectedPackage = selectedPackage;
+    }
+
+    public Package getSelectedPackage() {
+        return selectedPackage;
     }
 
     @Override
@@ -162,6 +180,15 @@ public class PackageListBox
     }
 
     public void onPackageSelected(final String selectedPackage) {
-        this.selectedPackage = selectedPackage;
+
+        setSelectedPackage(resolve(selectedPackage));
+    }
+
+    private String resolve(final String selectedPackage) {
+        if (Objects.equals(PackageItem.DEFAULT_PACKAGE_NAME, selectedPackage)) {
+            return "";
+        } else {
+            return selectedPackage;
+        }
     }
 }
